@@ -1,8 +1,7 @@
-/* Smail SCCS ID: @(#) addlink.c,v 1.3 1994/10/17 17:03:34 nm4 Exp */
-
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) addlink.c,v 1.3 1994/10/17 17:03:34 nm4 Exp";
+static char	*sccsid = "@(#)addlink.c	9.7 88/06/10";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:addlink.c,v 1.4 1997/02/09 21:50:34 woods Exp";
 #endif /* lint */
 
 #include "def.h"
