@@ -1,4 +1,3 @@
-/* Smail SCCS ID: @(#) config.h,v 1.7 1993/12/07 01:08:05 tron Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 
 /**************************************************************************
@@ -18,17 +17,23 @@
 #define SMAIL_3		/* changes for SMAIL-3 are #ifdef'd with this */
 
 #undef STRCHR
-#define BZERO
+#define BZERO		/* always avail. to smail compile */
 #undef MEMSET
 
+#undef SMALL		/* run slower (definitely), use less vm (maybe). */
+
 #undef UNAME
 #undef GETHOSTNAME
 #ifdef HAVE_UNAME
-#define UNAME
+# define UNAME
 #else
-#ifdef HAVE_GETHOSTNAME
-#define GETHOSTNAME
+# ifdef HAVE_GETHOSTNAME
+#  define GETHOSTNAME
+# endif
 #endif
+
+#ifdef HAVE_BIND
+# define RESOLVER	/* have internet domain name resolver */
 #endif
 
 /* default place for dbm output of makedb (or use -o at run-time) */
@@ -39,9 +44,9 @@
 #endif
 
 /*
- * pathalias defines an external named link, which clashes with
- * the link system call.  The link system call may have been defined
- * in one of the header files included by defs.h.
+ * Pathalias defines a type named link, which clashes with the link system
+ * call.  The link system call may have been defined in one of the header files
+ * included by defs.h.
  */
 
 #define link	palias_link
@@ -53,13 +58,19 @@
  **************************************************************************/
 
 
-
 #ifdef MAIN
 #ifndef lint
-static char	*c_sccsid = "@(#)config.h	9.2 89/03/03";
+static char	*c_sccsid = "@(#)config.h	9.6 95/05/04";
+static char	*c_rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:config.h,v 1.8 1997/02/09 21:50:44 woods Exp";
 #endif /*lint*/
 #endif /*MAIN*/
 
+/* the usual case: unix */
+#define	NULL_DEVICE	"/dev/null"
+#define	OK		0
+
+#include <exitcodes.h>
+
 /*
  * malloc/free fine tuned for pathalias.
  *
