@@ -1,25 +1,27 @@
-/* Smail SCCS ID: @(#) def.h,v 1.4 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 
 #ifndef lint
 #ifdef MAIN
-static char	*h_sccsid = "@(#) def.h,v 1.4 1994/10/18 13:28:12 nm4 Exp";
+static char	*h_sccsid = "@(#)def.h	9.9 95/05/04";
+static char	*h_rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:def.h,v 1.5 1997/02/09 21:50:47 woods Exp";
 #endif /*MAIN*/
 #endif /*lint*/
 
+#include "config.h"
+
 #include <stdio.h>
 #include <ctype.h>
-#include "config.h"
 
 typedef	long Cost;
 typedef struct node node;
 typedef struct link link;
+typedef struct dom dom;
 
 #ifdef lint
-#define vprintf fprintf
+#define Vprintf fprintf
 #else /*!lint -- this gives null effect warning*/
 /* because it's there ... */
-#define vprintf		!Vflag ? 0 : fprintf
+#define Vprintf		!Vflag ? 0 : fprintf
 #endif /*lint*/
 
 #define NTRACE	16	/* can trace up to NTRACE hosts/links */
@@ -59,7 +61,6 @@ typedef struct link link;
 #define n_private un2.nu_priv
 #define n_parent  un2.nu_par
 
-/* WARNING: if > 2^16 nodes, type of n_tloc must change */
 struct node {
 	char	*n_name;	/* host name */
 	link	*n_link;	/* adjacency list */
@@ -73,7 +74,11 @@ struct node {
 		node *nu_priv;	/* other privates in this file (parsing) */
 		node *nu_par;	/* parent in shortest path tree (mapping) */
 	} un2;
+#ifdef SMALL
 	unsigned short n_tloc;	/* back ptr to heap/hash table */
+#else
+	int	n_tloc;		/* back ptr to heap/hash table */
+#endif
 	unsigned short n_flag;		/* see manifests above */
 };
 
@@ -123,7 +128,6 @@ struct link {
 	short	l_flag;		/* right/left syntax, flags */
 	char	l_netop;	/* network operator */
 };
-
 #endif /*DEBUG*/
 
 #ifdef DEBUG
@@ -140,7 +144,11 @@ struct node {
 	node	*n_copy;
 	node	*n_private;
 	node	*n_parent;
-	unsigned short n_tloc;
+#ifdef SMALL
+	unsigned short n_tloc;	/* back ptr to heap/hash table */
+#else
+	int	n_tloc;		/* back ptr to heap/hash table */
+#endif
 	unsigned short n_flag;
 };
 struct link {
@@ -152,3 +160,10 @@ struct link {
 	char	l_netop;
 };
 #endif /*DEBUG*/
+
+/* doubly linked list for known and unknown domains */
+struct dom {
+	dom *next;
+	dom *prev;
+	char *name;
+};
