@@ -1,12 +1,13 @@
-/* Smail SCCS ID: @(#) local.c,v 1.3 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) local.c,v 1.3 1994/10/18 13:28:12 nm4 Exp";
+static char	*sccsid = "@(#)local.c	9.3 91/06/11";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:local.c,v 1.4 1997/02/09 21:50:50 woods Exp";
 #endif /* lint */
 
-#include <stdio.h>
 #include "config.h"
 
+#include <stdio.h>
+
 #ifdef	UNAME
 #include <sys/utsname.h>
 
