@@ -1,10 +1,14 @@
-/* Smail SCCS ID: @(#) main.c,v 1.3 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) main.c,v 1.3 1994/10/18 13:28:12 nm4 Exp";
+static char	*sccsid = "@(#)main.c	9.8 91/06/11";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:main.c,v 1.4 1997/02/09 21:50:52 woods Exp";
 #endif
 
-#define MAIN	/* for sccsid in header files */
+#ifndef VMS
+#define	MAIN	main
+#else
+#define	MAIN	XXmain
+#endif
 
 #include "def.h"
 
@@ -20,6 +24,7 @@ int Iflag;	/* ignore case (-i option) */
 int Tflag;	/* trace links (-t option) */
 int Vflag;	/* verbose (-v option) */
 int Fflag;	/* print cost of first hop */
+int InetFlag;	/* local host is w/in scope of DNS (-I flag) */
 int Lineno = 1;	/* line number within current input file */
 int Argc;	/* external copy of argc (for input files) */
 extern void die();
@@ -36,14 +41,15 @@ extern node *addnode();
 extern int getopt(), yyparse();
 extern void printit();
 
-#define USAGE "usage: %s [-vciDf] [-l localname] [-d deadlink] [-t tracelink] [-g edgeout] [-s treeout] [-a avoid] [files ...]\n"
+#define USAGE "usage: %s [-vciDfIp] [-l localname] [-d deadlink] [-t tracelink] [-g edgeout] [-s treeout] [-a avoid] [files ...]\n"
 
-main(argc, argv) 
+MAIN(argc, argv) 
 	register int argc; 
 	register char **argv;
 {	char *locname = 0, *bang;
 	register int c;
 	int errflg = 0;
+	int parseonly = 0;	/* -p */
 
 	setbuf(stderr, (char *) 0);
 	(void) allocation();	/* initialize data space monitoring */
@@ -51,7 +57,7 @@ main(argc, argv)
 	Argv = argv;
 	Argc = argc;
 
-	while ((c = getopt(argc, argv, "cd:Dfg:il:s:t:v")) != EOF)
+	while ((c = getopt(argc, argv, "cd:Dfg:iIl:ps:t:v")) != EOF)
 		switch(c) {
 		case 'c':	/* print cost info */
 			Cflag++;
@@ -76,16 +82,22 @@ main(argc, argv)
 		case 'i':	/* ignore case */
 			Iflag++;
 			break;
+		case 'I':	/* Internet connected */
+			InetFlag++;
+			break;
 		case 'l':	/* local name */
 			locname = optarg;
 			break;
+		case 'p':
+			parseonly = 1;
+			break;
 		case 's':	/* show shortest path tree */
 			Linkout = optarg;
 			break;
 		case 't':	/* trace this link */
 			if (tracelink(optarg) < 0) {
 				fprintf(stderr, "%s: can trace only %d links\n", Argv[0], NTRACE);
-				exit(1);
+				exit(EX_USAGE);
 			}
 			Tflag = 1;
 			break;
@@ -98,12 +110,12 @@ main(argc, argv)
 
 	if (errflg) {
 		fprintf(stderr, USAGE, Argv[0]);
-		exit(1);
+		exit(EX_USAGE);
 	}
 	argv += optind;		/* kludge for yywrap() */
 
 	if (*argv)
-		freopen("/dev/null", "r", stdin);
+		freopen(NULL_DEVICE, "r", stdin);
 	else
 		Cfile = "[stdin]";
 
@@ -122,23 +134,28 @@ main(argc, argv)
 
 	if (Vflag > 1)
 		hashanalyze();
-	vprintf(stderr, "%d nodes, %d links, alloc %ldk\n", 
+	Vprintf(stderr, "%d nodes, %d links, alloc %ldk\n", 
 				Ncount, Lcount, allocation());
 
+	if (parseonly != 0) {
+		wasted();
+		exit(EX_OK);
+	}
+
 	Cfile = "[backlinks]";	/* for tracing back links */
 	Lineno = 0;
 
 	/* compute shortest path tree */
 	mapit();
-	vprintf(stderr, "allocation is %ldk after mapping\n", allocation());
+	Vprintf(stderr, "allocation is %ldk after mapping\n", allocation());
 
 	/* traverse tree and print paths */
 	printit();
-	vprintf(stderr, "allocation is %ldk after printing\n", allocation());
+	Vprintf(stderr, "allocation is %ldk after printing\n", allocation());
 
 	wasted();	/* how much was wasted in memory allocation? */
 
-	return 0;
+	exit(EX_OK);
 }
 
 void
@@ -154,6 +171,6 @@ die(s)
 	abort();
 #else
 	fprintf(stderr, "%s: %s; notify the authorities\n", Argv[0], s);
-	exit(-1);
+	exit(EX_OSERR);
 #endif
 }
