@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#) makedb.c,v 1.7 1996/02/16 22:53:12 woods Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) makedb.c,v 1.7 1996/02/16 22:53:12 woods Exp";
+static char	*sccsid = "@(#)makedb.c	9.1 87/10/04";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:makedb.c,v 1.8 1997/02/09 21:50:54 woods Exp";
 #endif /* lint */
 
 #include <stdio.h>
@@ -48,7 +48,7 @@ main(argc, argv)
 
 		default:
 			fprintf(stderr, USAGE, ProgName);
-			exit(1);
+			exit(EX_USAGE);
 			break;
 		}
 
@@ -69,12 +69,12 @@ main(argc, argv)
 
 	if (append == 0 && dbfile(Ofile) != 0) {
 		perror_(Ofile);
-		exit(1);
+		exit(EX_IOERR);
 	}
 
 	if (dbminit(Ofile) < 0) {
 		perror_(Ofile);
-		exit(1);
+		exit(EX_IOERR);
 	}
 
 	if (optind == argc)
@@ -84,7 +84,7 @@ main(argc, argv)
 
 	dbmclose();
 
-	exit(0);
+	exit(EX_OK);
 }
 
 dbfile(dbf)
