@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#) mapaux.c,v 1.8 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) mapaux.c,v 1.8 1994/10/18 13:28:12 nm4 Exp";
+static char	*sccsid = "@(#)mapaux.c	9.8 91/06/23";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:mapaux.c,v 1.9 1997/02/09 21:50:56 woods Exp";
 #endif /* lint */
 
 #include "def.h"
@@ -32,7 +32,6 @@ STATIC void dumpnode(), untangle(), dfs();
 STATIC int height();
 STATIC link *lcopy();
 
-
 /*
  * slide everything from Table[low] to Table[high]
  * up toward the high end.  make room!  make room!
@@ -332,7 +331,7 @@ ncopy(parent, l)
 
 #ifdef DEBUG
 	if (Vflag > 1)
-		vprintf(stderr, "<%s> <- %s\n", l->l_to->n_name, parent->n_name);
+		Vprintf(stderr, "<%s> <- %s\n", l->l_to->n_name, parent->n_name);
 #endif
 	n = l->l_to;
 	if (REUSABLE(n, l)) {
@@ -354,12 +353,14 @@ ncopy(parent, l)
 }
 
 /*
- * copy l, but don't include any links to parent.
+ * copy n's links but don't copy any terminal links
+ * since n is itself at the end of a terminal link.
  *
  * this is a little messier than it should be, because
- * of the funny test for ancestry, and because it wants
- * to be recursive, but the recursion might be very deep
- * (for a long link list), so it's done iteratively.
+ * it wants to be recursive, but the recursion might be
+ * very deep (for a long link list), so it iterates.
+ *
+ * why copy any links other than aliases?  hmmm ...
  */
 STATIC link *
 lcopy(parent, n)
@@ -368,22 +369,18 @@ lcopy(parent, n)
 	link *first = 0, *last = 0;
  
 	for (l = n->n_link; l != 0; l = l->l_next) {
-		/* avoid vestigial descendants */
-		if ((l->l_to->n_flag & MAPPED) != 0
-#if 0
-		/*
-		 * this was added from an unofficial pathalias patch,
-		 * but it apparently causes some problems with some
-		 * existing map entries
-		 *   - problem reported by chip@tct.com
-		 */
-		 || (l->l_flag & LTERMINAL) != 0
-#endif
-		 || ALTEREGO(l->l_to, parent))
+		/* skip if dest is already mapped */
+		if ((l->l_to->n_flag & MAPPED) != 0)
+			continue;
+		/* don't copy terminal links */
+		if ((l->l_flag & LTERMINAL) != 0)
+			continue;
+		/* comment needed */
+		if (ALTEREGO(l->l_to, parent))
 			continue;
 #ifdef DEBUG
 		if (Vflag > 1)
-			vprintf(stderr, "\t-> %s\n", l->l_to->n_name);
+			Vprintf(stderr, "\t-> %s\n", l->l_to->n_name);
 #endif
 		NumLcopy++;
 		lcp = newlink();
