@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#) mapit.c,v 1.3 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) mapit.c,v 1.3 1994/10/18 13:28:12 nm4 Exp";
+static char	*sccsid = "@(#)mapit.c	9.18 95/07/12";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:mapit.c,v 1.4 1997/02/09 21:50:58 woods Exp";
 #endif
 
 #include "def.h"
@@ -45,13 +45,15 @@ STATIC int dehash(), skiplink(), skipterminalalias();
 STATIC Cost costof();
 STATIC node *mappedcopy();
 
+#define MAPTRACE(n1, n2) (Tflag && maptrace(n1, n2))
+
 /* transform the graph to a shortest-path tree by marking tree edges */
 void
 mapit()
 {	register node *n;
 	register link *l;
 
-	vprintf(stderr, "*** mapping\ttcount = %ld\n", Tcount);
+	Vprintf(stderr, "*** mapping\ttcount = %ld\n", Tcount);
 	Tflag = Tflag && Vflag;		/* tracing here only if verbose */
 	/* re-use the hash table space for the heap */
 	Heap = (link **) Table;
@@ -75,17 +77,18 @@ mapit()
 	do {
 		Heaphighwater = Nheap;
 		while ((l = min_node()) != 0) {
+			register node *nptr;
+
 			l->l_flag |= LTREE;
 			n = l->l_to;
 			if (n->n_flag & MAPPED)		/* sanity check */
 				die("mapped node in heap");
-			if (Tflag && maptrace(n, n))
-				otracereport(n);	/* tracing */
+			if (MAPTRACE(n, n)) otracereport(n);	/* tracing */
 			chkheap(1); chkgap();		/* debugging */
 			n->n_flag |= MAPPED;
 			heapchildren(n);	/* add children to heap */
 		}
-		vprintf(stderr, "heap hiwat %d\nalloc %ldk, ncopy = %ld, nlink = %ld, lcopy = %ld\n", Heaphighwater, allocation(), NumNcopy, Nlink, NumLcopy);
+		Vprintf(stderr, "heap hiwat %d\nalloc %ldk, ncopy = %ld, nlink = %ld, lcopy = %ld\n", Heaphighwater, allocation(), NumNcopy, Nlink, NumLcopy);
 
 		if (Nheap != 0)		/* sanity check */
 			die("null entry in heap");
@@ -125,7 +128,7 @@ heapchildren(n)
 	for (l = n->n_link; l; l = l->l_next) {
 
 		next = l->l_to;		/* neighboring node */
-		mtrace = Tflag && maptrace(n, next);
+		mtrace = MAPTRACE(n, next);
 
 		if (l->l_flag & LTREE)
 			continue;
@@ -183,14 +186,10 @@ heapchildren(n)
 	}
 }
 
-/* 
- * bizarro special case.  this merits comment.
- * 
+/*
  * n is a terminal node just sucked out of the heap, next is an alias
- * for n.  because n is terminal, it must have one or more "copies."
- * if next is one of those copies, don't put next in the heap.
- *
- * does that clear things up?
+ * for n.  if n was heaped because of a copy (ALTEREGO) of next, don't
+ * heap next -- it will happen over and over and over and ...
  */
 STATIC int
 skipterminalalias(n, next)
@@ -226,6 +225,8 @@ skiplink(l, parent, cost, trace)
 	if (n->n_tloc >= Hashpart)
 		return 0;
 
+	if (n->n_tloc == 0)
+		die("reached unheaped node");
 	lheap = Heap[n->n_tloc];
 
 	/* examine links to nets that require gateways */
@@ -264,7 +265,7 @@ skiplink(l, parent, cost, trace)
 	return 0;
 }
 
-/* compute cost to l->l_to via parent */
+/* compute cost to next (l->l_to) via prev */
 STATIC Cost
 costof(prev, l)
 	register node *prev;
@@ -277,6 +278,8 @@ costof(prev, l)
 
 	next = l->l_to;
 	cost = prev->n_cost + l->l_cost;	/* basic cost */
+	if (cost >= INF)
+		return cost + 1;
 
 	/*
 	 * heuristics:
@@ -286,15 +289,15 @@ costof(prev, l)
 	 *    charge for getting into a gatewayed net (except at a gateway).
 	 *    discourage mixing of syntax (when prev is a host).
 	 *
-	 * life was simpler when pathalias computed true shortest paths.
+	 * life was simpler when pathalias truly computed shortest paths.
 	 */
 	if (DEADLINK(l))
 		cost += INF;				/* dead link */
-	if (DEADHOST(prev))
+	else if (DEADHOST(prev))
 		cost += INF;				/* dead parent */
-	if (GATEWAYED(next) && !(l->l_flag & LGATEWAY))
+	else if (GATEWAYED(next) && !(l->l_flag & LGATEWAY))
 		cost += INF;				/* not gateway */
-	if (!ISANET(prev)) {
+	else if (!ISANET(prev)) {
 		if ((NETDIR(l) == LLEFT && (prev->n_flag & HASRIGHT))
 		 || (NETDIR(l) == LRIGHT && (prev->n_flag & HASLEFT)))
 			cost += INF;			/* mixed syntax */
@@ -304,7 +307,6 @@ costof(prev, l)
 }
 
 /* binary heap implementation of priority queue */
-
 STATIC void
 insert(l)
 	link *l;
@@ -501,11 +503,12 @@ backlinks()
 	/* hosts from Hashpart to Tabsize are unreachable */
 	for (i = Hashpart; i < Tabsize; i++) {
 		nomap = Table[i];
-		/* if a copy has been mapped, we're ok */
 		if (nomap->n_copy != nomap) {
+			/* a copy has been mapped */
 			dehash(nomap);
 			Table[nomap->n_tloc] = 0;
 			nomap->n_tloc = 0;
+			nomap->n_flag |= MAPPED;
 			continue;
 		}
 
@@ -533,7 +536,7 @@ backlinks()
 			child = n;
 		}
 		if (child == 0)
-			continue;
+			continue;	/* can't backlink this node */
 		(void) dehash(nomap);
 		l = addlink(child, nomap, INF, DEFNET, DEFDIR);	/* INF cost */
 		nomap->n_parent = child;
@@ -543,7 +546,7 @@ backlinks()
 		if (Vflag > 1)
 			fprintf(stderr, "backlink: %s <- %s\n", nomap->n_name, child->n_name);
 	}
-	vprintf(stderr, "%d backlinks\n", Nheap);
+	Vprintf(stderr, "%d backlinks\n", Nheap);
 }
 
 /* find a mapped copy of n if it exists */
@@ -644,21 +647,21 @@ chkheap(i)
 	for (i = 1; i < Nheap; i++) {
 		link *l;
 
-		vprintf(stderr, "%5d %-16s", i, Heap[i]->l_to->n_name);
+		Vprintf(stderr, "%5d %-16s", i, Heap[i]->l_to->n_name);
 		if ((l = Heap[i]->l_to->n_link) != 0) do {
-			vprintf(stderr, "%-16s", l->l_to->n_name);
+			Vprintf(stderr, "%-16s", l->l_to->n_name);
 		} while ((l = l->l_next) != 0);
-		vprintf(stderr, "\n");
+		Vprintf(stderr, "\n");
 	}
 	for (i = Hashpart; i < Tabsize; i++) {
 		link *l;
 		node *n;
 
-		vprintf(stderr, "%5d %-16s", i, Table[i]->n_name);
+		Vprintf(stderr, "%5d %-16s", i, Table[i]->n_name);
 		if ((l = Table[i]->n_link) != 0) do {
-			vprintf(stderr, "%-16s", l->l_to->n_name);
+			Vprintf(stderr, "%-16s", l->l_to->n_name);
 		} while ((l = l->l_next) != 0);
-		vprintf(stderr, "\n");
+		Vprintf(stderr, "\n");
 	}
 #endif /*00*/
 		
