@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#) mem.c,v 1.6 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) mem.c,v 1.6 1994/10/18 13:28:12 nm4 Exp";
+static char	*sccsid = "@(#)mem.c	9.6 92/08/25";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:mem.c,v 1.7 1997/02/09 21:51:03 woods Exp";
 #endif
 
 #include "def.h"
@@ -14,18 +14,23 @@ extern long allocation();
 /* imports */
 extern char *Netchars;
 extern int Vflag;
-#if defined(SMAIL_3) && defined(ANSI_C) && !defined(NO_VOID_SBRK)
-extern void *sbrk();
-#else
-extern char *sbrk();
-#endif
 extern void die();
 #ifndef SMAIL_3
 extern int strlen();
 #endif
+#ifdef DEBUG
+# if defined(SMAIL_3) && defined(ANSI_C) && !defined(NO_VOID_SBRK)
+extern void *sbrk();
+# else
+extern char *sbrk();
+# endif
+#endif
 
 /* privates */
 STATIC void nomem();
+#ifdef MYMALLOC
+STATIC void addtoheap();
+#endif
 static link *Lcache;
 static unsigned int Memwaste;
 
@@ -61,6 +66,16 @@ newnode()
 	return rval;
 }
 
+dom *
+newdom()
+{	register dom *rval;
+
+	if ((rval = (dom * ) calloc(1, sizeof(dom))) == 0)
+		nomem();
+
+	return rval;
+}
+
 char	*
 strsave(s)
 	char *s;
@@ -99,8 +114,6 @@ freetable(t, size)
 	long size;
 {
 #ifdef MYMALLOC
-	extern void addtoheap();
-
 	addtoheap((char *) t, size * sizeof(node *));
 #else
 	free((char *) t);
@@ -120,6 +133,7 @@ nomem()
 long
 allocation()
 {
+#ifdef DEBUG
 	static char *dataspace;
 	long rval;
 
@@ -127,14 +141,17 @@ allocation()
 		dataspace = sbrk(0);	/* &end? */
 		return 0;
 	}
-#ifdef SMAIL_3
+# ifdef SMAIL_3
 	rval = ((char *)sbrk(0) - dataspace)/1024;
-#else
+# else
 	rval = (sbrk(0) - dataspace)/1024;
-#endif
+# endif
 	if (rval < 0)			/* funny architecture? */
 		rval = -rval;
 	return rval;
+#else
+	return 0;
+#endif
 }
 
 /* how much memory has been wasted? */
@@ -143,7 +160,7 @@ wasted()
 {
 	if (Memwaste == 0)
 		return;
-	vprintf(stderr, "memory allocator wasted %ld bytes\n", Memwaste);
+	Vprintf(stderr, "memory allocator wasted %ld bytes\n", Memwaste);
 }
 
 #ifdef MYMALLOC
