@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#) printit.c,v 1.4 1994/10/18 13:28:12 nm4 Exp */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#) printit.c,v 1.4 1994/10/18 13:28:12 nm4 Exp";
+static char	*sccsid = "@(#)printit.c	9.4 89/02/07";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_92:printit.c,v 1.5 1997/02/09 21:51:08 woods Exp";
 #endif
 
 #include "def.h"
@@ -304,7 +304,7 @@ printdomain(n, path, cost)
 	if (!ISADOMAIN(n->n_parent)) {
 		/* top-level domain */
 		if (n->n_flag & ISPRIVATE) {
-			vprintf(stderr, "ignoring private top-level domain %s\n", n->n_name);
+			Vprintf(stderr, "ignoring private top-level domain %s\n", n->n_name);
 			return;
 		}
 	} else {
