@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_91:alloc.c,v 1.7 1996/05/29 18:48:14 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_92:alloc.c,v 1.8 1997/01/18 20:42:04 woods Exp"
  */
 
 /*
@@ -288,7 +288,7 @@ malloc_block()
     struct block *block;	/* ptr to the new block */
 
     /* allocate the block */
-    block = (struct block *) bmalloc((unsigned) sizeof(struct block), master);
+    block = (struct block *) bmalloc((unsigned) sizeof(struct block), &master);
     block->cnt = 0;
     block->next = NULL;
 
