@@ -1,4 +1,4 @@
-/* @(#) $Id: direct.h,v 1.4 1994/10/17 17:04:37 nm4 Exp $ */
+/* @(#) direct.h,v 1.7 1996/02/16 23:01:29 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -27,6 +27,7 @@ struct director {
     char *default_user;			/* default user name for permissions */
     char *default_group;		/* default group name */
     char *default_home;			/* default home directory */
+    char *domains;                      /* domains for this director */
     char *set_user;			/* set user for permissions */
     char *set_group;			/* set group for permissions */
     char *set_home;			/* set home directory */
@@ -47,6 +48,7 @@ struct direct_driver {
     void (*verify)();			/* function to perform verification */
     void (*finish)();			/* function to free resources */
     char *(*builder)();			/* fun to read from director file */
+    void (*dumper)();			/* fun to dump configuration */
 };
 
 /* flags for the director.flags field */
@@ -55,5 +57,6 @@ struct direct_driver {
 #define CACHED_DIRECTOR		0x0004	/* read in cache data */
 #define SENDER_OKAY		0x0008	/* assumes me_too operation */
 #define IGNORE_ALIAS_MATCH	0x0010	/* ignore aliases that match parent */
+#define USER_IGNORE_CASE	0x0020	/* lower user b4 matching w/mailbox */
 
 #endif	/* DIRECT_H */
