@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_91:lookup.c,v 1.28 1996/08/27 04:21:56 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_92:lookup.c,v 1.30 1997/01/18 21:16:45 woods Exp"
  */
 
 /*
@@ -353,6 +353,7 @@ bsearch_close(db)
     struct bsearch_db *db;
 {
     (void) fclose(db->f);
+    xfree(db->name);
     xfree((char *)db);
 }
 
@@ -538,6 +539,7 @@ lsearch_close(db)
     struct lsearch_db *db;
 {
     (void) fclose(db->f);
+    xfree(db->name);
     xfree((char *)db);
 }
 
@@ -853,6 +855,7 @@ dbmbase_close(db)
 	opendb = NULL;
     }
 #endif
+    xfree(db->name);
     xfree((char *)db);
     return;
 }
@@ -993,7 +996,7 @@ yp_open(name, proto, retries, interval, statp, db, error)
     char **error;			/* store error message here */
 {
     register struct yp_db *priv;
-    register char *p;
+    register char *p, *pname;
     int err;				/* error from yp functions */
     /* XXX: third arg to yp_order() is (ulong *) on Solaris-2 */
     int order;				/* output from yp_order */
@@ -1004,18 +1007,17 @@ yp_open(name, proto, retries, interval, statp, db, error)
 #endif
 
     priv = (struct yp_db *)xmalloc(sizeof(*priv));
+    pname = COPY_STRING(name);
 
     /* is a YP domain specified? */
-    p = index(name, ':');
+    p = index(pname, ':');
     if (p == NULL) {
 	/* no, use the default YP domain */
 	priv->domain = NULL;
-	priv->map = name;
+	priv->map = pname;
     } else {
-	/* yes, make a copy and use it */
-	priv->domain = xmalloc(p - name + 1);
-	(void) memcpy(priv->domain, name, p - name);
-	priv->domain[p - name] = '\0';
+	priv->domain = pname;
+	priv->domain[p - pname] = '\0';
 	priv->map = p + 1;
     }
 
@@ -1112,6 +1114,8 @@ yp_close(db)
 {
     if (db->domain) {
 	xfree(db->domain);
+    } else {
+	xfree(db->map);
     }
     xfree((char *)db);
     return;
@@ -1398,6 +1402,7 @@ aliasni_lookup(db, key, value, error)
 
 /* private data structure */
 struct nisplus_db {
+    char		*name;
     struct proto	*proto;
     char		*table;
     int			fieldnum;
@@ -1426,14 +1431,15 @@ nisplus_open(name, proto, retries, interval, statp, db, error)
     priv->fieldnum = 1;
     priv->retries = retries;
     priv->interval = interval;
+    priv->name = COPY_STRING(name);
 
     /* check for directive to change field number */
     /* we use @ in character 0 because NIS+ strings cannot start with @ */
-    if ( name[0] == '@' ) {
+    if (priv->name[0] == '@') {
 	char	*offset;
 
-        priv->fieldnum = atoi(name+1);
-	offset = index(name,',');
+        priv->fieldnum = atoi(priv->name + 1);
+	offset = index(priv->name,',');
 	if ( offset ) {
             priv->table = COPY_STRING(offset+1);
         } else {
@@ -1444,7 +1450,7 @@ nisplus_open(name, proto, retries, interval, statp, db, error)
 	}
     } else {
         priv->fieldnum = 1;
-        priv->table = name;
+        priv->table = priv->name;
     }
 
     /* if stat required, just zero it out, there is nothing to put there */
@@ -1453,8 +1459,8 @@ nisplus_open(name, proto, retries, interval, statp, db, error)
     }
 
     /* find offset to domain name, advance past the last comma */
-    if ( !(domain = rindex(name,','))) {
-	domain = name;
+    if ( !(domain = rindex(priv->name,','))) {
+	domain = priv->name;
     } else {
 	domain++;
     }
@@ -1538,7 +1544,8 @@ nisplus_open(name, proto, retries, interval, statp, db, error)
 
 	/* sleep interval for retry */
 	if ( retries > 0 ) {
-	    DEBUG2(DBG_DRIVER_HI, "nisplus_open: will retry open(%s) after %d seconds\n", name, interval);
+	    DEBUG2(DBG_DRIVER_HI, "nisplus_open: will retry open(%s) after %d seconds\n",
+		   priv->name, interval);
 	    sleep ( interval );
 	}
     } while ( retries-- > 0 );
@@ -1557,6 +1564,7 @@ static void
 nisplus_close(db)
     struct nisplus_db *db;
 {
+    xfree(db->priv->name);
     xfree((char *)db);
     return;
 }
