@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_91:smailconf.c,v 1.28 1996/05/29 14:50:24 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_92:smailconf.c,v 1.29 1997/01/18 20:40:38 woods Exp"
  */
 
 /*
@@ -1108,7 +1108,7 @@ make_lib_fn(fn)
 	return NULL;
     }
     if (fn[0] == '/' || (fn[0] == '-' && fn[1] == '\0')) {
-	return fn;
+	return COPY_STRING(fn);
     }
     if (smail_lib_dir == NULL) {
 	return NULL;
