@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_91:sysdep.c,v 1.54 1997/01/15 02:42:56 woods Exp
+#ident	"@(#)smail/src:RELEASE-3_2_0_92:sysdep.c,v 1.55 1997/01/21 23:23:14 woods Exp
  */
 
 /*
@@ -521,14 +521,15 @@ fopen_as_user(fn, type, uid, gid, mode)
 	errno = EACCES;
 	return NULL;
     }
-
     /*
-     * This is the classic way for a setuid program to use a file safely as
-     * a user without worrying about race conditions.  We open the file
-     * first as root, then as the user in a child process, and we compare
-     * st_dev and st_ino for both files, failing if they are not identical.
+     * This is the classic way for a setuid program to use a file safely as a
+     * user without worrying about race conditions.  If the file doesn't exist
+     * we first must create it as the user.  In all cases we then open the file
+     * first as root (no create, no truncation unless the file is to be owned
+     * by root), then as the user in a child process, and we compare st_dev and
+     * st_ino for both files, failing if they are not identical.
      */
-    if (geteuid() == 0 && uid != 0 && gid != 0) {
+    if (geteuid() == 0 && uid != 0) {
         /*
 	 * If writing (incl. appending), check whether the file already exists
 	 * as we need it to do the access check properly.
@@ -546,11 +547,13 @@ fopen_as_user(fn, type, uid, gid, mode)
 		/* NOTREACHED */
 
 	    case 0:
-		if (setgid(gid) != 0) {
-		    DEBUG3(DBG_DRIVER_LO, "fopen_as_user(): create child setgid(%d): %s (uid was %d).\n",
-			   gid, strerror(errno), uid);
-		    _exit(errno + 1);
-		    /* NOTREACHED */
+		if (getegid() != gid) {	/* this is probably silly */
+		    if (setgid(gid) != 0) {
+			DEBUG3(DBG_DRIVER_LO, "fopen_as_user(): create child setgid(%d): %s (uid was %d).\n",
+			       gid, strerror(errno), uid);
+			_exit(errno + 1);
+			/* NOTREACHED */
+		    }
 		}
 		if (setuid(uid) != 0) {
 		    DEBUG2(DBG_DRIVER_LO, "fopen_as_user(): create child setuid(%d): %s.\n",
@@ -592,14 +595,19 @@ fopen_as_user(fn, type, uid, gid, mode)
 	    }
 	}
     }
+    /*
+     * If we're not running as euid==0, then we're assuming the file does exist
+     * and has group write permission aka SysV policy.  There is a race
+     * condition here where the user might remove the file just after we've
+     * created it above, but if so, too bad for the user -- mailer readers
+     * should truncate the empty mailbox, not remove it.
+     */
+#define CREAT_TRUNC_ARE_OK	((geteuid() == 0 && uid == 0) || \
+				 (geteuid() != 0 && access(fn, F_OK) != EOF))
     if (type[0] == 'w') {
-	/*
-	 * NB:  No truncate flag here otherwise we'd damage a file before
-	 * checking access.
-	 */
-	fd = open(fn, O_WRONLY, mode);
+	fd = open(fn, O_WRONLY | (CREAT_TRUNC_ARE_OK ? (O_CREAT | O_TRUNC) : 0), mode);
     } else if (type[0] == 'a') {
-	fd = open(fn, O_WRONLY | O_APPEND, mode);
+	fd = open(fn, O_WRONLY | O_APPEND | (CREAT_TRUNC_ARE_OK ? (O_CREAT) : 0), mode);
     } else {
 	fd = open(fn, O_RDONLY, mode);
     }
@@ -607,7 +615,7 @@ fopen_as_user(fn, type, uid, gid, mode)
 	DEBUG2(DBG_DRIVER_MID, "fopen_as_user(): open(%s): %s.\n", fn, strerror(errno));
 	return(NULL);
     }
-    if (geteuid() == 0 && uid != 0 && gid != 0) {
+    if (geteuid() == 0 && uid != 0) {
 	if (fstat(fd, &stb_root) != 0) {
 	    int oerrno = errno;
 
@@ -629,11 +637,13 @@ fopen_as_user(fn, type, uid, gid, mode)
 	    /* NOTREACHED */
 
 	case 0:
-	    if (setgid(gid) != 0) {
-		DEBUG3(DBG_DRIVER_LO, "fopen_as_user(): test child setgid(%d): %s (uid was %d).\n",
-		       gid, strerror(errno), uid);
-		_exit(errno + 1);
-		/* NOTREACHED */
+	    if (getegid() != gid) {	/* this is probably silly */
+		if (setgid(gid) != 0) {
+		    DEBUG3(DBG_DRIVER_LO, "fopen_as_user(): test child setgid(%d): %s (uid was %d).\n",
+			   gid, strerror(errno), uid);
+		    _exit(errno + 1);
+		    /* NOTREACHED */
+		}
 	    }
 	    if (setuid(uid) != 0) {
 		DEBUG2(DBG_DRIVER_LO, "fopen_as_user(): test childsetuid(%d): %s.\n",
