@@ -1,4 +1,4 @@
-/* @(#) mkline.c,v 1.3 1992/07/11 11:40:08 tron Exp */
+/* @(#) mkline.c,v 1.4 1997/01/18 20:43:05 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -27,7 +27,7 @@
 
 char *program;				/* argv[0] from main */
 int debug = 0;
-FILE *errfile = stderr;
+FILE *errfile;
 int use_tabs_p = FALSE;
 int ignore_keys_p = FALSE;
 
@@ -40,6 +40,7 @@ main(argc, argv)
     int list_files_p = FALSE;		/* TRUE for -l option */
 
     program = *argv++;
+    errfile = stderr;
 
     /* if -l, process mailing list files */
     while (*argv && (*argv)[0] == '-' && (*argv)[1] != '\0') {
