@@ -1,4 +1,4 @@
-/* @(#) mksort.c,v 1.5 1992/09/06 01:10:32 tron Exp */
+/* @(#) mksort.c,v 1.6 1997/01/18 20:43:09 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -27,7 +27,7 @@
 
 char *program;				/* argv[0] from main */
 int debug = 0;
-FILE *errfile = stderr;
+FILE *errfile;
 
 static int cmp(), cmpic();
 static char **mkvectors();
@@ -47,6 +47,7 @@ main(argc, argv)
     int i;
 
     program = *argv++;
+    errfile = stderr;
 
     /* if -f, then perform case-folded comparisons */
     if (*argv && EQ(*argv, "-f")) {
